==> qtjambi-dbus-6.5.4-sources.jar: io/qt/dbus/QDBusSignature.java <==
package io.qt.dbus;

import io.qt.*;


/**
 * <p>Enables the programmer to identify the SIGNATURE type provided by the D-Bus typesystem</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qdbussignature.html">QDBusSignature</a></code></p>
 */
public class QDBusSignature extends QtObject
    implements java.lang.Comparable<io.qt.dbus.@StrictNonNull QDBusSignature>,
            java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdbussignature.html#QDBusSignature">QDBusSignature::<wbr/>QDBusSignature()</a></code></p>
     */
    public QDBusSignature(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDBusSignature instance);
    
    /**
     * <p>See <code>QDBusSignature::<wbr/>QDBusSignature(QString&amp;&amp;)</code></p>
     */
    public QDBusSignature(java.lang.@NonNull CharSequence sig){
        super((QPrivateConstructor)null);
        initialize_native(this, sig);
    }
    
    private native static void initialize_native(QDBusSignature instance, java.lang.CharSequence sig);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdbussignature.html#QDBusSignature-3">QDBusSignature::<wbr/>QDBusSignature(QString)</a></code></p>
     */
    public QDBusSignature(java.lang.@NonNull String signature){
        super((QPrivateConstructor)null);
        initialize_native(this, signature);
    }
    
    private native static void initialize_native(QDBusSignature instance, java.lang.String signature);
    
    /**
     * <p>See <code>operator&lt;(QDBusSignature,<wbr/>QDBusSignature)</code></p>
     */
    @QtUninvokable
    private final boolean operator_less(io.qt.dbus.@NonNull QDBusSignature rhs){
        return operator_less_native_cref_QDBusSignature(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(rhs));
    }
    
    @QtUninvokable
    private native boolean operator_less_native_cref_QDBusSignature(long __this__nativeId, long rhs);
    
    /**
     * <p>See <code>operator==(QDBusSignature,<wbr/>QDBusSignature)</code></p>
     */
    @QtUninvokable
    public final boolean equals(io.qt.dbus.@NonNull QDBusSignature rhs){
        return equals_native_cref_QDBusSignature(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(rhs));
    }
    
    @QtUninvokable
    private native boolean equals_native_cref_QDBusSignature(long __this__nativeId, long rhs);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdbussignature.html#setSignature">QDBusSignature::<wbr/>setSignature(QString)</a></code></p>
     */
    @QtUninvokable
    public final void setSignature(java.lang.@NonNull String signature){
        setSignature_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), signature);
    }
    
    @QtUninvokable
    private native void setSignature_native_cref_QString(long __this__nativeId, java.lang.String signature);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdbussignature.html#signature">QDBusSignature::<wbr/>signature()const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String signature(){
        return signature_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String signature_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdbussignature.html#swap">QDBusSignature::<wbr/>swap(QDBusSignature&amp;)</a></code></p>
     */
    @QtUninvokable
    public final void swap(io.qt.dbus.@StrictNonNull QDBusSignature other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QDBusSignature(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void swap_native_ref_QDBusSignature(long __this__nativeId, long other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QDBusSignature(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>operator==(QDBusSignature,<wbr/>QDBusSignature)</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.dbus.QDBusSignature) {
            return equals((io.qt.dbus.QDBusSignature) other);
        }

        return false;
    }

    /**
     * <p>See <code>operator&lt;(QDBusSignature,<wbr/>QDBusSignature)</code></p>
     */
    /**
     * {@inheritDoc}
     */
    @QtUninvokable
    public int compareTo(io.qt.dbus.@StrictNonNull QDBusSignature other) {
        if (equals(other)) return 0;
        else if (operator_less(other)) return -1;
        else return 1;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QDBusSignature)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QDBusSignature clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDBusSignature clone_native(long __this_nativeId);
}

==> qtjambi-dbus-6.5.6-sources.jar: io/qt/dbus/QDBusSignature.java <==
package io.qt.dbus;

import io.qt.*;


/**
 * <p>Enables the programmer to identify the SIGNATURE type provided by the D-Bus typesystem</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qdbussignature.html">QDBusSignature</a></code></p>
 */
public class QDBusSignature extends QtObject
    implements java.lang.Comparable<io.qt.dbus.@StrictNonNull QDBusSignature>,
            java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdbussignature.html#QDBusSignature">QDBusSignature::<wbr/>QDBusSignature()</a></code></p>
     */
    public QDBusSignature(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDBusSignature instance);
    
    /**
     * <p>See <code>QDBusSignature::<wbr/>QDBusSignature(QDBusSignature)</code></p>
     */
    public QDBusSignature(io.qt.dbus.@NonNull QDBusSignature other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QDBusSignature instance, io.qt.dbus.QDBusSignature other);
    
    /**
     * <p>See <code>QDBusSignature::<wbr/>QDBusSignature(QString&amp;&amp;)</code></p>
     */
    public QDBusSignature(java.lang.@NonNull CharSequence sig){
        super((QPrivateConstructor)null);
        initialize_native(this, sig);
    }
    
    private native static void initialize_native(QDBusSignature instance, java.lang.CharSequence sig);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdbussignature.html#QDBusSignature-3">QDBusSignature::<wbr/>QDBusSignature(QString)</a></code></p>
     */
    public QDBusSignature(java.lang.@NonNull String signature){
        super((QPrivateConstructor)null);
        initialize_native(this, signature);
    }
    
    private native static void initialize_native(QDBusSignature instance, java.lang.String signature);
    
    /**
     * <p>See <code>operator&lt;(QDBusSignature,<wbr/>QDBusSignature)</code></p>
     */
    @QtUninvokable
    private final boolean operator_less(io.qt.dbus.@NonNull QDBusSignature rhs){
        return operator_less_native_cref_QDBusSignature(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(rhs));
    }
    
    @QtUninvokable
    private native boolean operator_less_native_cref_QDBusSignature(long __this__nativeId, long rhs);
    
    /**
     * <p>See <code>operator==(QDBusSignature,<wbr/>QDBusSignature)</code></p>
     */
    @QtUninvokable
    public final boolean equals(io.qt.dbus.@NonNull QDBusSignature rhs){
        return equals_native_cref_QDBusSignature(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(rhs));
    }
    
    @QtUninvokable
    private native boolean equals_native_cref_QDBusSignature(long __this__nativeId, long rhs);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdbussignature.html#setSignature">QDBusSignature::<wbr/>setSignature(QString)</a></code></p>
     */
    @QtUninvokable
    public final void setSignature(java.lang.@NonNull String signature){
        setSignature_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), signature);
    }
    
    @QtUninvokable
    private native void setSignature_native_cref_QString(long __this__nativeId, java.lang.String signature);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdbussignature.html#signature">QDBusSignature::<wbr/>signature()const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String signature(){
        return signature_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String signature_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdbussignature.html#swap">QDBusSignature::<wbr/>swap(QDBusSignature&amp;)</a></code></p>
     */
    @QtUninvokable
    public final void swap(io.qt.dbus.@StrictNonNull QDBusSignature other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QDBusSignature(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void swap_native_ref_QDBusSignature(long __this__nativeId, long other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QDBusSignature(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>operator==(QDBusSignature,<wbr/>QDBusSignature)</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.dbus.QDBusSignature) {
            return equals((io.qt.dbus.QDBusSignature) other);
        }

        return false;
    }

    /**
     * <p>See <code>operator&lt;(QDBusSignature,<wbr/>QDBusSignature)</code></p>
     */
    /**
     * {@inheritDoc}
     */
    @QtUninvokable
    public int compareTo(io.qt.dbus.@StrictNonNull QDBusSignature other) {
        if (equals(other)) return 0;
        else if (operator_less(other)) return -1;
        else return 1;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QDBusSignature)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
    <p>See <code>QDBusSignature::<wbr/>QDBusSignature(QDBusSignature)</code></p>
     */
    @QtUninvokable
    @Override
    public QDBusSignature clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDBusSignature clone_native(long __this_nativeId);
}
